Module utilities

Module utilities 

Miscellaneous utility functions

Functions

util_activity_menu
Use the elements of a String vector to create a terminal-based numbered menu. Returns the number of the item chosen by the user.
util_concat_strvec
Concatenate a vector of Strings into a single String that is then returned.
util_concat_strvec_flag
Concatenates a vector of Strings. Places a flag char between pieces.
util_flaggedtxt_2vec
Breaks up a String that contains flag characters, saving the sections between the flags as elements of a vector that is then returned. Any character can be used as the flag. The author generally uses ‘’ as the flag.
util_get_lastchar
Returns the very last character of a String.
util_wait_for_enter
Does just what the name says. Waits for the user to press Enter before continuing execution.