Miscellaneous utility functions
Functions
- util_
activity_ menu - Use the elements of a String vector to create a terminal-based numbered menu. Returns the number of the item chosen by the user.
- util_
concat_ strvec - Concatenate a vector of Strings into a single String that is then returned.
- util_
concat_ strvec_ flag - Concatenates a vector of Strings. Places a flag char between pieces.
- util_
flaggedtxt_ 2vec - Breaks up a String that contains flag characters, saving the sections between the flags as elements of a vector that is then returned. Any character can be used as the flag. The author generally uses ‘’ as the flag.
- util_
get_ lastchar - Returns the very last character of a String.
- util_
wait_ for_ enter - Does just what the name says. Waits for the user to press
Enterbefore continuing execution.